<?php

/*
 * This file is part of Resume.PHP.
 *
 * (copyleft) R. Eric Wheeler <sikofitt@gmail.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

/**
 * Created by PhpStorm.
 * User: eric
 * Date: 7/17/16
 * Time: 3:26 PM
 */

namespace Sikofitt\Resume;

use App;
use Knp\Snappy\Pdf as Snappy;
use Symfony\Component\HttpFoundation\Request;

class Pdf
{
    /**
     * @var string
     */
    private $host;

    /**
     * @var Snappy
     */
    private $snappy;

    /**
     * @var App
     */
    private $app;

    /**
     * @var Request
     */
    private $request;

    /**
     * @var ResumeParser
     */
    private $resume;

    /**
     * Pdf constructor.
     *
     * @param App     $app
     * @param Request $request
     */
    public function __construct(App $app, Request $request)
    {
        $this->app = $app;
        $this->request = $request;
        $this->resume = new ResumeParser($this->app);
        $this->snappy = new Snappy($app->getRootDirectory() . '/vendor/bin/wkhtmltopdf-amd64');
    }

    /**
     * @return string
     */
    public function render()
    {
        $content = $this->getIndex();
        $cover = $this->getCover();
        $title = $this->getTitle();

        return $this->snappy->getOutputFromHtml(
            $content, [
                'lowquality'           => false,
                'collate'              => true,
                'margin-right'         => 1,
                'margin-left'          => 1,
                'title'                => $title,
                'header-font-size'     => 12,
                'cover'                => $cover,
                'no-stop-slow-scripts' => true,
                'stop-slow-scripts'    => false,
                'enable-javascript'    => true,
                'no-outline'           => true,
                'outline'              => false,
                'dump-outline'         => $this->app->getLogDirectory() . '/pdf-outline-' . md5(time()),
            ]
        );
    }

    /**
     * @return string
     */
    public function getIndex()
    {
        $host =  $this->request->getSchemeAndHttpHost();

        return $this->app->renderView('index.html.twig', [
            'renderPdf'    => true,
            'baseUrl'      => $host,
            'basics'       => $this->resume->getBasics(),
            'work'         => $this->resume->getWork(),
            'volunteer'    => $this->resume->getVolunteer(),
            'education'    => $this->resume->getEducation(),
            'awards'       => $this->resume->getAwards(),
            'publications' => $this->resume->getPublications(),
            'skills'       => $this->resume->getSkills(),
            'languages'    => $this->resume->getLanguages(),
            'interests'    => $this->resume->getInterests(),
            'references'   => $this->resume->getReferences(),
        ]);
    }
    public function setHost($host)
    {
        $this->host = $host;
    }
    public function getHost()
    {
        return $this->host;
    }
    /**
     * @return string
     */
    public function getCover()
    {
        $host = $this->request->getSchemeAndHttpHost();
        return $this->app->renderView('cover.html.twig', [
            'baseUrl'   => $host,
            'renderPdf' => true,
            'basics'    => $this->resume->getBasics(),
        ]);
    }

    /**
     * @return string
     */
    public function getTitle()
    {
        $date = new \DateTimeImmutable('now');
        $date = $date->format('c');
        $title = $this->app->config('app.title') ?: 'Resume';
        return sprintf('%s (%s)', $title, $date);
    }
}
