<?php

/*
 * This file is part of Resume.PHP.
 *
 * (copyleft) R. Eric Wheeler <sikofitt@gmail.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Sikofitt\Resume;

use App;

/**
 * Class ResumeParser
 *
 * @package Sikofitt\Resume
 */
class ResumeParser extends \ArrayObject implements \JsonSerializable, \ArrayAccess
{
    /**
     * @var
     */
    private $input;
    /**
     * @var
     */
    private $basics;
    /**
     * @var
     */
    private $work;
    /**
     * @var
     */
    private $volunteer;
    /**
     * @var
     */
    private $education;
    /**
     * @var
     */
    private $awards;
    /**
     * @var
     */
    private $publications;
    /**
     * @var
     */
    private $skills;
    /**
     * @var
     */
    private $languages;
    /**
     * @var
     */
    private $interests;
    /**
     * @var
     */
    private $references;

    /**
     * ResumeParser constructor.
     *
     * @param App    $app
     * @param int    $flags
     * @param string $iterator_class
     */
    public function __construct(App $app, $flags = 0, $iterator_class = 'ArrayIterator')
    {
        $this->app = $app;
        $this->input = $this->app->decodeFile($app->getResumeJson(), $app->getResumeSchema());

        parent::__construct($this->input, $flags, $iterator_class);
        $this
            ->setBasics($this->offsetGet('basics'))
            ->setWork($this->offsetGet('work'))
            ->setVolunteer($this->offsetGet('volunteer'))
            ->setEducation($this->offsetGet('education'))
            ->setAwards($this->offsetGet('awards'))
            ->setPublications($this->offsetGet('publications'))
            ->setSkills($this->offsetGet('skills'))
            ->setLanguages($this->offsetGet('languages'))
            ->setInterests($this->offsetGet('interests'))
            ->setReferences($this->offsetGet('references'));
    }

    /**
     * @return mixed
     */
    public function jsonSerialize()
    {
        return $this->app->encode($this->input, $this->app->getResumeSchema());
    }

    /**
     * @return mixed
     */
    public function getBasics()
    {
        return $this->basics;
    }

    /**
     * @param mixed $basics
     *
     * @return ResumeParser
     */
    public function setBasics($basics)
    {
        $this->basics = $basics;
        return $this;
    }

    /**
     * @return mixed
     */
    public function getWork()
    {
        return $this->work;
    }

    /**
     * @param mixed $work
     *
     * @return ResumeParser
     */
    public function setWork($work)
    {
        $this->work = $work;
        return $this;
    }

    /**
     * @return mixed
     */
    public function getVolunteer()
    {
        return $this->volunteer;
    }

    /**
     * @param mixed $volunteer
     *
     * @return ResumeParser
     */
    public function setVolunteer($volunteer)
    {
        $this->volunteer = $volunteer;
        return $this;
    }

    /**
     * @return mixed
     */
    public function getEducation()
    {
        return $this->education;
    }

    /**
     * @param mixed $education
     *
     * @return ResumeParser
     */
    public function setEducation($education)
    {
        $this->education = $education;
        return $this;
    }

    /**
     * @return mixed
     */
    public function getAwards()
    {
        return $this->awards;
    }

    /**
     * @param mixed $awards
     *
     * @return ResumeParser
     */
    public function setAwards($awards)
    {
        $this->awards = $awards;
        return $this;
    }

    /**
     * @return mixed
     */
    public function getPublications()
    {
        return $this->publications;
    }

    /**
     * @param mixed $publications
     *
     * @return ResumeParser
     */
    public function setPublications($publications)
    {
        $this->publications = $publications;
        return $this;
    }

    /**
     * @return mixed
     */
    public function getSkills()
    {
        return $this->skills;
    }

    /**
     * @param mixed $skills
     *
     * @return ResumeParser
     */
    public function setSkills($skills)
    {
        $this->skills = $skills;
        return $this;
    }

    /**
     * @return mixed
     */
    public function getLanguages()
    {
        return $this->languages;
    }

    /**
     * @param mixed $languages
     *
     * @return ResumeParser
     */
    public function setLanguages($languages)
    {
        $this->languages = $languages;
        return $this;
    }

    /**
     * @return mixed
     */
    public function getInterests()
    {
        return $this->interests;
    }

    /**
     * @param mixed $interests
     *
     * @return ResumeParser
     */
    public function setInterests($interests)
    {
        $this->interests = $interests;
        return $this;
    }

    /**
     * @return mixed
     */
    public function getReferences()
    {
        return $this->references;
    }

    /**
     * @param mixed $references
     *
     * @return ResumeParser
     */
    public function setReferences($references)
    {
        $this->references = $references;
        return $this;
    }
}
